@@ -32,6 +32,8 @@ type TestRun struct {
 	Thresholds map[string][]string `json:"thresholds"`
 	// Duration of test in seconds. -1 for unknown length, 0 for continuous running.
 	Duration int64 `json:"duration"`
+	// Archive is the test script archive to (maybe) upload to the cloud.
+	Archive *lib.Archive `json:"-"`
 }
 
 // LogEntry can be used by the cloud to tell k6 to log something to the console,
@@ -61,6 +63,13 @@ type LoginResponse struct {
 	Token string `json:"token"`
 }
 
+// ValidateTokenResponse is the response of a token validation.
+type ValidateTokenResponse struct {
+	IsValid bool   `json:"is_valid"`
+	Message string `json:"message"`
+	Token   string `json:"token-info"`
+}
+
 func (c *Client) handleLogEntriesFromCloud(ctrr CreateTestRunResponse) {
 	logger := c.logger.WithField("source", "grafana-k6-cloud")
 	for _, logEntry := range ctrr.Logs {
@@ -74,26 +83,84 @@ func (c *Client) handleLogEntriesFromCloud(ctrr CreateTestRunResponse) {
 }
 
 // CreateTestRun is used when a test run is being executed locally, while the
-// results are streamed to the cloud, i.e. `k6 run --out cloud script.js`.
+// results are streamed to the cloud, i.e. `k6 cloud run --local-execution` or `k6 run --out cloud script.js`.
 func (c *Client) CreateTestRun(testRun *TestRun) (*CreateTestRunResponse, error) {
 	url := fmt.Sprintf("%s/tests", c.baseURL)
-	req, err := c.NewRequest("POST", url, testRun)
+
+	// Because the kind of request we make can vary depending on the test run configuration, we delegate
+	// its creation to a helper.
+	request, err := c.makeCreateTestRunRequest(url, testRun)
 	if err != nil {
 		return nil, err
 	}
 
-	ctrr := CreateTestRunResponse{}
-	err = c.Do(req, &ctrr)
+	response := CreateTestRunResponse{}
+	err = c.Do(request, &response)
 	if err != nil {
 		return nil, err
 	}
 
-	c.handleLogEntriesFromCloud(ctrr)
-	if ctrr.ReferenceID == "" {
+	c.handleLogEntriesFromCloud(response)
+	if response.ReferenceID == "" {
 		return nil, fmt.Errorf("failed to get a reference ID")
 	}
 
-	return &ctrr, nil
+	return &response, nil
+}
+
+// makeCreateTestRunRequest creates a new HTTP request for creating a test run.
+//
+// If the test run archive isn't set, the request will be a regular JSON request with the test run information.
+// Otherwise, the request will be a multipart form request containing the test run information and the archive file.
+func (c *Client) makeCreateTestRunRequest(url string, testRun *TestRun) (*http.Request, error) {
+	// If the test run archive isn't set, we are not uploading an archive and can use the regular request JSON format.
+	if testRun.Archive == nil {
+		return c.NewRequest(http.MethodPost, url, testRun)
+	}
+
+	// Otherwise, we need to create a multipart form request containing the test run information as
+	// well as the archive file.
+	fields := [][2]string{
+		{"name", testRun.Name},
+		{"project_id", strconv.FormatInt(testRun.ProjectID, 10)},
+		{"vus", strconv.FormatInt(testRun.VUsMax, 10)},
+		{"duration", strconv.FormatInt(testRun.Duration, 10)},
+	}
+
+	var buffer bytes.Buffer
+	multipartWriter := multipart.NewWriter(&buffer)
+
+	for _, field := range fields {
+		if err := multipartWriter.WriteField(field[0], field[1]); err != nil {
+			return nil, err
+		}
+	}
+
+	fw, err := multipartWriter.CreateFormFile("file", "archive.tar")
+	if err != nil {
+		return nil, err
+	}
+
+	if err = testRun.Archive.Write(fw); err != nil {
+		return nil, err
+	}
+
+	// Close the multipart writer to finalize the form data
+	err = multipartWriter.Close()
+	if err != nil {
+		return nil, err
+	}
+
+	// Create a new POST request with the multipart form data
+	req, err := http.NewRequest(http.MethodPost, url, &buffer) //nolint:noctx
+	if err != nil {
+		return nil, err
+	}
+
+	// Set the content type to the one generated by the multipart writer
+	req.Header.Set("Content-Type", multipartWriter.FormDataContentType())
+
+	return req, nil
 }
 
 // StartCloudTestRun starts a cloud test run, i.e. `k6 cloud script.js`.
@@ -188,8 +255,7 @@ func (c *Client) TestFinished(referenceID string, thresholds ThresholdResult, ta
 
 // GetTestProgress for the provided referenceID.
 func (c *Client) GetTestProgress(referenceID string) (*TestProgressResponse, error) {
-	url := fmt.Sprintf("%s/test-progress/%s", c.baseURL, referenceID)
-	req, err := c.NewRequest(http.MethodGet, url, nil)
+	req, err := c.NewRequest(http.MethodGet, c.baseURL+"/test-progress/"+referenceID, nil)
 	if err != nil {
 		return nil, err
 	}
@@ -205,9 +271,7 @@ func (c *Client) GetTestProgress(referenceID string) (*TestProgressResponse, err
 
 // StopCloudTestRun tells the cloud to stop the test with the provided referenceID.
 func (c *Client) StopCloudTestRun(referenceID string) error {
-	url := fmt.Sprintf("%s/tests/%s/stop", c.baseURL, referenceID)
-
-	req, err := c.NewRequest("POST", url, nil)
+	req, err := c.NewRequest("POST", c.baseURL+"/tests/"+referenceID+"/stop", nil)
 	if err != nil {
 		return err
 	}
@@ -215,17 +279,14 @@ func (c *Client) StopCloudTestRun(referenceID string) error {
 	return c.Do(req, nil)
 }
 
+type validateOptionsRequest struct {
+	Options lib.Options `json:"options"`
+}
+
 // ValidateOptions sends the provided options to the cloud for validation.
 func (c *Client) ValidateOptions(options lib.Options) error {
-	url := fmt.Sprintf("%s/validate-options", c.baseURL)
-
-	data := struct {
-		Options lib.Options `json:"options"`
-	}{
-		options,
-	}
-
-	req, err := c.NewRequest("POST", url, data)
+	data := validateOptionsRequest{Options: options}
+	req, err := c.NewRequest("POST", c.baseURL+"/validate-options", data)
 	if err != nil {
 		return err
 	}
@@ -233,19 +294,15 @@ func (c *Client) ValidateOptions(options lib.Options) error {
 	return c.Do(req, nil)
 }
 
+type loginRequest struct {
+	Email    string `json:"email"`
+	Password string `json:"password"`
+}
+
 // Login the user with the specified email and password.
 func (c *Client) Login(email string, password string) (*LoginResponse, error) {
-	url := fmt.Sprintf("%s/login", c.baseURL)
-
-	data := struct {
-		Email    string `json:"email"`
-		Password string `json:"password"`
-	}{
-		email,
-		password,
-	}
-
-	req, err := c.NewRequest("POST", url, data)
+	data := loginRequest{Email: email, Password: password}
+	req, err := c.NewRequest("POST", c.baseURL+"/login", data)
 	if err != nil {
 		return nil, err
 	}
@@ -258,3 +315,24 @@ func (c *Client) Login(email string, password string) (*LoginResponse, error) {
 
 	return &lr, nil
 }
+
+type validateTokenRequest struct {
+	Token string `json:"token"`
+}
+
+// ValidateToken calls the endpoint to validate the Client's token and returns the result.
+func (c *Client) ValidateToken() (*ValidateTokenResponse, error) {
+	data := validateTokenRequest{Token: c.token}
+	req, err := c.NewRequest("POST", c.baseURL+"/validate-token", data)
+	if err != nil {
+		return nil, err
+	}
+
+	vtr := ValidateTokenResponse{}
+	err = c.Do(req, &vtr)
+	if err != nil {
+		return nil, err
+	}
+
+	return &vtr, nil
+}
