@@ -1,8 +1,7 @@
 import http from "k6/http";
 import exec from 'k6/execution';
 import { browser } from "k6/browser";
-import { sleep, fail } from 'k6';
-import { expect } from "https://jslib.k6.io/k6-testing/0.5.0/index.js";
+import { sleep, check, fail } from 'k6';
 
 const BASE_URL = __ENV.BASE_URL || "https://quickpizza.grafana.com";
 
@@ -27,7 +26,9 @@ export const options = {
 
 export function setup() {
   let res = http.get(BASE_URL);
-  expect(res.status, `Got unexpected status code ${res.status} when trying to setup. Exiting.`).toBe(200);
+  if (res.status !== 200) {
+    exec.test.abort(`Got unexpected status code ${res.status} when trying to setup. Exiting.`);
+  }
 }
 
 export default async function() {
@@ -36,13 +37,21 @@ export default async function() {
 
   try {
     await page.goto(BASE_URL);
-    await expect.soft(page.locator("h1")).toHaveText("Looking to break out of your pizza routine?");
+
+    checkData = await page.locator("h1").textContent();
+    check(page, {
+      header: checkData === "Looking to break out of your pizza routine?",
+    });
 
     await page.locator('//button[. = "Pizza, Please!"]').click();
     await page.waitForTimeout(500);
 
     await page.screenshot({ path: "screenshot.png" });
-    await expect.soft(page.locator("div#recommendations")).not.toHaveText("");
+
+    checkData = await page.locator("div#recommendations").textContent();
+    check(page, {
+      recommendation: checkData !== "",
+    });
   } catch (error) {
     fail(`Browser iteration failed: ${error.message}`);
   } finally {
