@@ -9,7 +9,6 @@ import (
 	"github.com/mstoykov/k6-taskqueue-lib/taskqueue"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common"
-	"go.k6.io/k6/internal/js/modules/k6/browser/k6ext"
 	k6common "go.k6.io/k6/js/common"
 )
 
@@ -34,7 +33,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing new frame check options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Check(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -54,13 +53,13 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, err
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				err := f.Click(selector, popts)
 				return nil, err //nolint:wrapcheck
 			}), nil
 		},
 		"content": func() *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.Content() //nolint:wrapcheck
 			})
 		},
@@ -69,7 +68,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing double click options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Dblclick(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -79,7 +78,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing frame dispatch event options: %w", err)
 			}
 			earg := exportArg(eventInit)
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.DispatchEvent(selector, typ, earg, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -89,7 +88,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			}
 			funcString := pageFunc.String()
 			gopts := exportArgs(gargs)
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.Evaluate(funcString, gopts...)
 			}), nil
 		},
@@ -99,7 +98,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			}
 			funcString := pageFunc.String()
 			gopts := exportArgs(gargs)
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				jsh, err := f.EvaluateHandle(funcString, gopts...)
 				if err != nil {
 					return nil, err //nolint:wrapcheck
@@ -112,7 +111,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing fill options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Fill(selector, value, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -121,12 +120,12 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing focus options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Focus(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
 		"frameElement": func() *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				fe, err := f.FrameElement()
 				if err != nil {
 					return nil, err //nolint:wrapcheck
@@ -139,7 +138,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing getAttribute options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				s, ok, err := f.GetAttribute(selector, name, popts)
 				if err != nil {
 					return nil, err //nolint:wrapcheck
@@ -221,7 +220,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := gopts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing frame navigation options to %q: %w", url, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				resp, err := f.Goto(url, gopts)
 				if err != nil {
 					return nil, err //nolint:wrapcheck
@@ -235,7 +234,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing hover options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Hover(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -244,7 +243,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing inner HTML options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.InnerHTML(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -253,7 +252,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing inner text options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.InnerText(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -262,7 +261,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing input value options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.InputValue(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -271,7 +270,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing isChecked options of selector %q: %w", selector, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.IsChecked(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -281,7 +280,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing isDisabled options of selector %q: %w", selector, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.IsDisabled(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -290,7 +289,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parse isEditable options of selector %q: %w", selector, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.IsEditable(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -299,7 +298,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parse isEnabled options of selector %q: %w", selector, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.IsEnabled(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -308,7 +307,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parse isHidden options of selector %q: %w", selector, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.IsHidden(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -317,7 +316,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parse isVisible options of selector %q: %w", selector, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.IsVisible(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -336,7 +335,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parse press options of selector %q on key %q: %w", selector, key, err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Press(selector, key, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -346,12 +345,12 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing select option options: %w", err)
 			}
 
-			convValues, err := common.ConvertSelectOptionValues(rt, values)
+			convValues, err := ConvertSelectOptionValues(rt, values)
 			if err != nil {
 				return nil, fmt.Errorf("parsing select options values: %w", err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.SelectOption(selector, convValues, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -361,7 +360,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing frame set check options: %w", err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.SetChecked(selector, checked, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -370,7 +369,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing setContent options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.SetContent(html, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -385,7 +384,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing setInputFiles parameter: %w", err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.SetInputFiles(selector, pfiles, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -394,7 +393,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			if err := popts.Parse(vu.Context(), opts); err != nil {
 				return nil, fmt.Errorf("parsing frame tap options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Tap(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -404,7 +403,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing text content options: %w", err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				s, ok, err := f.TextContent(selector, popts)
 				if err != nil {
 					return nil, err //nolint:wrapcheck
@@ -416,7 +415,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			}), nil
 		},
 		"title": func() *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return f.Title()
 			})
 		},
@@ -426,7 +425,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing type options: %w", err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Type(selector, text, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -436,7 +435,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing frame uncheck options %q: %w", selector, err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.Uncheck(selector, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -449,7 +448,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("frame waitForFunction: %w", err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (result any, reason error) {
+			return promise(vu, func() (result any, reason error) {
 				return f.WaitForFunction(js, popts, pargs...) //nolint:wrapcheck
 			}), nil
 		},
@@ -459,7 +458,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing waitForLoadState %q options: %w", state, err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, f.WaitForLoadState(state, popts) //nolint:wrapcheck
 			}), nil
 		},
@@ -472,7 +471,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 				return nil, fmt.Errorf("parsing wait for selector %q options: %w", selector, err)
 			}
 
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				eh, err := f.WaitForSelector(selector, popts)
 				if err != nil {
 					return nil, err //nolint:wrapcheck
@@ -481,17 +480,17 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			}), nil
 		},
 		"waitForTimeout": func(timeout int64) *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				f.WaitForTimeout(timeout)
 				return nil, nil
 			})
 		},
 		"waitForURL": func(url sobek.Value, opts sobek.Value) (*sobek.Promise, error) {
-			return waitForURLBodyImpl(vu, f, url, opts)
+			return waitForURLBody(vu, f, url, opts)
 		},
 	}
 	maps["$"] = func(selector string) *sobek.Promise {
-		return k6ext.Promise(vu.Context(), func() (any, error) {
+		return promise(vu, func() (any, error) {
 			eh, err := f.Query(selector, common.StrictModeOff)
 			if err != nil {
 				return nil, err //nolint:wrapcheck
@@ -508,7 +507,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 		})
 	}
 	maps["$$"] = func(selector string) *sobek.Promise {
-		return k6ext.Promise(vu.Context(), func() (any, error) {
+		return promise(vu, func() (any, error) {
 			ehs, err := f.QueryAll(selector)
 			if err != nil {
 				return nil, err //nolint:wrapcheck
