@@ -6,18 +6,17 @@ import (
 	"github.com/grafana/sobek"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common"
-	"go.k6.io/k6/internal/js/modules/k6/browser/k6ext"
 )
 
 func mapKeyboard(vu moduleVU, kb *common.Keyboard) mapping {
 	return mapping{
 		"down": func(key string) *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, kb.Down(key) //nolint:wrapcheck
 			})
 		},
 		"up": func(key string) *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, kb.Up(key) //nolint:wrapcheck
 			})
 		},
@@ -26,7 +25,7 @@ func mapKeyboard(vu moduleVU, kb *common.Keyboard) mapping {
 			if err != nil {
 				return nil, fmt.Errorf("parsing keyboard options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, kb.Press(key, kbopts)
 			}), nil
 		},
@@ -35,12 +34,12 @@ func mapKeyboard(vu moduleVU, kb *common.Keyboard) mapping {
 			if err != nil {
 				return nil, fmt.Errorf("parsing keyboard options: %w", err)
 			}
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, kb.Type(text, kbopts)
 			}), nil
 		},
 		"insertText": func(text string) *sobek.Promise {
-			return k6ext.Promise(vu.Context(), func() (any, error) {
+			return promise(vu, func() (any, error) {
 				return nil, kb.InsertText(text) //nolint:wrapcheck
 			})
 		},
