@@ -196,7 +196,7 @@ func TestMappings(t *testing.T) {
 		"mapConsoleMessage": {
 			apiInterface: (*consoleMessageAPI)(nil),
 			mapp: func() mapping {
-				return mapConsoleMessage(moduleVU{VU: vu}, common.PageOnEvent{
+				return mapConsoleMessage(moduleVU{VU: vu}, common.PageEvent{
 					ConsoleMessage: &common.ConsoleMessage{},
 				})
 			},
@@ -204,7 +204,7 @@ func TestMappings(t *testing.T) {
 		"mapMetricEvent": {
 			apiInterface: (*metricEventAPI)(nil),
 			mapp: func() mapping {
-				return mapMetricEvent(moduleVU{VU: vu}, common.PageOnEvent{
+				return mapMetricEvent(moduleVU{VU: vu}, common.PageEvent{
 					Metric: &common.MetricEvent{},
 				})
 			},
@@ -348,7 +348,7 @@ type pageAPI interface { //nolint:interfacebloat
 	IsVisible(selector string, opts sobek.Value) (bool, error)
 	Locator(selector string, opts sobek.Value) *common.Locator
 	MainFrame() *common.Frame
-	On(event common.PageOnEventName, handler func(common.PageOnEvent) error) error
+	On(event common.PageEventName, handler func(common.PageEvent) error) error
 	Opener() pageAPI
 	Press(selector string, key string, opts sobek.Value) error
 	Query(selector string) (*common.ElementHandle, error)
@@ -371,6 +371,8 @@ type pageAPI interface { //nolint:interfacebloat
 	Title() (string, error)
 	Type(selector string, text string, opts sobek.Value) error
 	Uncheck(selector string, opts sobek.Value) error
+	Unroute(url string) error
+	UnrouteAll() error
 	URL() (string, error)
 	ViewportSize() map[string]float64
 	WaitForFunction(fn, opts sobek.Value, args ...sobek.Value) (any, error)
@@ -380,6 +382,7 @@ type pageAPI interface { //nolint:interfacebloat
 	WaitForTimeout(timeout int64)
 	WaitForURL(url string, opts sobek.Value) (*sobek.Promise, error)
 	WaitForResponse(url string, opts sobek.Value) (*sobek.Promise, error)
+	WaitForRequest(url string, opts sobek.Value) (*sobek.Promise, error)
 	Workers() []*common.Worker
 }
 
@@ -393,7 +396,7 @@ type consoleMessageAPI interface {
 
 // metricEventAPI is the interface of a metric event.
 type metricEventAPI interface {
-	Tag(matchesRegex common.K6BrowserCheckRegEx, patterns common.TagMatches) error
+	Tag(rm common.RegExMatcher, patterns common.TagMatches) error
 }
 
 // frameAPI is the interface of a CDP target frame.
@@ -558,6 +561,8 @@ type locatorAPI interface { //nolint:interfacebloat
 	ContentFrame() *common.FrameLocator
 	Count() (int, error)
 	Dblclick(opts sobek.Value) error
+	Evaluate(pageFunc sobek.Value, arg ...sobek.Value) (any, error)
+	EvaluateHandle(pageFunc sobek.Value, arg ...sobek.Value) (common.JSHandleAPI, error)
 	SetChecked(checked bool, opts sobek.Value) error
 	Check(opts sobek.Value) error
 	Uncheck(opts sobek.Value) error
