@@ -1,23 +1,23 @@
 package common
 
 import (
+	"cmp"
 	"context"
 	"errors"
 	"fmt"
 	"math"
 	"reflect"
+	"slices"
+	"strconv"
 	"strings"
 	"time"
 
 	"github.com/chromedp/cdproto/cdp"
 	"github.com/chromedp/cdproto/dom"
-	"github.com/grafana/sobek"
 	"go.opentelemetry.io/otel/attribute"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common/js"
 	"go.k6.io/k6/internal/js/modules/k6/browser/k6ext"
-
-	k6common "go.k6.io/k6/js/common"
 )
 
 // Common error types for element visibility.
@@ -472,87 +472,6 @@ func (h *ElementHandle) press(apiCtx context.Context, key string, opts KeyboardO
 	return nil
 }
 
-func ConvertSelectOptionValues(rt *sobek.Runtime, values sobek.Value) ([]any, error) {
-	if k6common.IsNullish(values) {
-		return nil, nil
-	}
-
-	var (
-		opts []any
-		t    = values.Export()
-	)
-	switch values.ExportType().Kind() {
-	case reflect.Slice:
-		var sl []interface{}
-		if err := rt.ExportTo(values, &sl); err != nil {
-			return nil, fmt.Errorf("options: expected array, got %T", values)
-		}
-
-		for _, item := range sl {
-			switch item := item.(type) {
-			case string:
-				// Strings will match values or labels
-				valOpt := SelectOption{Value: new(string)}
-				*valOpt.Value = item
-				labelOpt := SelectOption{Label: new(string)}
-				*labelOpt.Label = item
-				opts = append(opts, &valOpt, &labelOpt)
-			case map[string]interface{}:
-				opt, err := extractSelectOptionFromMap(item)
-				if err != nil {
-					return nil, err
-				}
-
-				opts = append(opts, opt)
-			default:
-				return nil, fmt.Errorf("options: expected string or object, got %T", item)
-			}
-		}
-	case reflect.Map:
-		var raw map[string]interface{}
-		if err := rt.ExportTo(values, &raw); err != nil {
-			return nil, fmt.Errorf("options: expected object, got %T", values)
-		}
-
-		opt, err := extractSelectOptionFromMap(raw)
-		if err != nil {
-			return nil, err
-		}
-
-		opts = append(opts, opt)
-	case reflect.TypeOf(&ElementHandle{}).Kind():
-		opts = append(opts, t.(*ElementHandle)) //nolint:forcetypeassert
-	case reflect.TypeOf(sobek.Object{}).Kind():
-		obj := values.ToObject(rt)
-		opt := SelectOption{}
-		for _, k := range obj.Keys() {
-			switch k {
-			case "value":
-				opt.Value = new(string)
-				*opt.Value = obj.Get(k).String()
-			case "label":
-				opt.Label = new(string)
-				*opt.Label = obj.Get(k).String()
-			case "index":
-				opt.Index = new(int64)
-				*opt.Index = obj.Get(k).ToInteger()
-			}
-		}
-		opts = append(opts, &opt)
-	case reflect.String:
-		// Strings will match values or labels
-		valOpt := SelectOption{Value: new(string)}
-		*valOpt.Value = t.(string) //nolint:forcetypeassert
-		labelOpt := SelectOption{Label: new(string)}
-		*labelOpt.Label = t.(string) //nolint:forcetypeassert
-		opts = append(opts, &valOpt, &labelOpt)
-	default:
-		return nil, fmt.Errorf("options: unsupported type %T", values)
-	}
-
-	return opts, nil
-}
-
 func (h *ElementHandle) selectOption(apiCtx context.Context, values []any) (any, error) {
 	fn := `
 		(node, injected, values) => {
@@ -576,44 +495,6 @@ func (h *ElementHandle) selectOption(apiCtx context.Context, values []any) (any,
 	return result, nil
 }
 
-func extractSelectOptionFromMap(v map[string]interface{}) (*SelectOption, error) {
-	opt := &SelectOption{}
-	for k, raw := range v {
-		switch k {
-		case "value":
-			opt.Value = new(string)
-
-			v, ok := raw.(string)
-			if !ok {
-				return nil, fmt.Errorf("options[%v]: expected string, got %T", k, raw)
-			}
-
-			*opt.Value = v
-		case "label":
-			opt.Label = new(string)
-
-			v, ok := raw.(string)
-			if !ok {
-				return nil, fmt.Errorf("options[%v]: expected string, got %T", k, raw)
-			}
-			*opt.Label = v
-		case "index":
-			opt.Index = new(int64)
-
-			switch raw := raw.(type) {
-			case int:
-				*opt.Index = int64(raw)
-			case int64:
-				*opt.Index = raw
-			default:
-				return nil, fmt.Errorf("options[%v]: expected int, got %T", k, raw)
-			}
-		}
-	}
-
-	return opt, nil
-}
-
 func (h *ElementHandle) selectText(apiCtx context.Context) error {
 	fn := `
 		(node, injected) => {
@@ -847,8 +728,8 @@ func (h *ElementHandle) count(apiCtx context.Context, selector string) (int, err
 	}
 	switch r := result.(type) {
 	case float64:
-		if r < float64(math.MinInt) || r > float64(math.MaxInt) {
-			return 0, fmt.Errorf("value %v out of range for int type", r)
+		if r < float64(math.MinInt32) || r > float64(math.MaxInt32) {
+			return 0, fmt.Errorf("value %v out of range for int32 type", r)
 		}
 		return int(r), nil
 	default:
@@ -1381,15 +1262,35 @@ func (h *ElementHandle) queryAll(selector string, eval evalFunc) (_ []*ElementHa
 		return nil, err //nolint:wrapcheck
 	}
 
-	els := make([]*ElementHandle, 0, len(props))
-	for _, prop := range props {
+	type indexedElem struct {
+		index int
+		elem  *ElementHandle
+	}
+
+	indexedElems := make([]indexedElem, 0, len(props))
+	for key, prop := range props {
 		if el := prop.AsElement(); el != nil {
-			els = append(els, el)
+			// DOM elements are stored with numeric indices ("0", "1", "2", ...)
+			// per JavaScript's array-like object specification.
+			idx, err := strconv.Atoi(key)
+			if err != nil {
+				return nil, fmt.Errorf("parsing element index %q for selector %q: %w", key, selector, err)
+			}
+			indexedElems = append(indexedElems, indexedElem{index: idx, elem: el})
 		} else if err := prop.Dispose(); err != nil {
 			return nil, fmt.Errorf("disposing property while querying all selectors %q: %w", selector, err)
 		}
 	}
 
+	slices.SortFunc(indexedElems, func(a, b indexedElem) int {
+		return cmp.Compare(a.index, b.index)
+	})
+
+	els := make([]*ElementHandle, 0, len(indexedElems))
+	for _, ie := range indexedElems {
+		els = append(els, ie.elem)
+	}
+
 	return els, nil
 }
 
