@@ -205,16 +205,6 @@ func createWaitForEventPredicateHandler(
 	return ch, evCancelFn
 }
 
-// panicOrSlowMo panics if err is not nil, otherwise applies slow motion.
-//
-//nolint:unused
-func panicOrSlowMo(ctx context.Context, err error) {
-	if err != nil {
-		k6ext.Panic(ctx, "%w", err)
-	}
-	applySlowMo(ctx)
-}
-
 // TrimQuotes removes surrounding single or double quotes from s.
 // We're not using strings.Trim() to avoid trimming unbalanced values,
 // e.g. `"'arg` shouldn't change.
@@ -249,3 +239,42 @@ func escapesSobekValues(args ...any) bool {
 	}
 	return false
 }
+
+// patternMatcherFunc is a function that matches a string against a pattern.
+type patternMatcherFunc func(string) (bool, error)
+
+// RegExMatcher is a function that matches a pattern against
+// a string and returns true if they match, false otherwise.
+type RegExMatcher func(pattern, str string) (bool, error)
+
+// newPatternMatcher returns a [patternMatcherFunc] that uses string matching for
+// quoted strings, and ECMAScript (Sobek) regex matching for others. If the pattern
+// is empty or a single quote, it matches any string.
+func newPatternMatcher(pattern string, rm RegExMatcher) (patternMatcherFunc, error) {
+	if pattern == "" || pattern == "''" {
+		return func(s string) (bool, error) { return true, nil }, nil
+	}
+	if isQuotedText(pattern) {
+		return func(s string) (bool, error) { return "'"+s+"'" == pattern, nil }, nil
+	}
+	if rm == nil {
+		return nil, fmt.Errorf("regex matcher must be provided")
+	}
+	return func(s string) (bool, error) {
+		ok, err := rm(pattern, s)
+		if err != nil {
+			return false, fmt.Errorf("matching %q against pattern %q: %w", s, pattern, err)
+		}
+		return ok, nil
+	}, nil
+}
+
+// Match evaluates the supplied string against the given pattern using the provided
+// [RegExMatcher] for regex patterns. The matcher behavior is determined by [newPatternMatcher].
+func (rm RegExMatcher) Match(pattern, s string) (bool, error) {
+	m, err := newPatternMatcher(pattern, rm)
+	if err != nil {
+		return false, fmt.Errorf("matching %q against pattern %q: %w", s, pattern, err)
+	}
+	return m(s)
+}
