@@ -80,7 +80,7 @@ func TestConsoleLogParse(t *testing.T) {
 
 			done := make(chan bool)
 
-			eventHandler := func(event common.PageOnEvent) error {
+			eventHandler := func(event common.PageEvent) error {
 				defer close(done)
 				assert.Equal(t, tt.want, event.ConsoleMessage.Text)
 				return nil
