@@ -11,12 +11,14 @@ import (
 	"time"
 
 	"github.com/sirupsen/logrus"
+
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/metrics"
 
 	protov1 "github.com/golang/protobuf/proto" //nolint:staticcheck,nolintlint // this is the old v1 version
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
+	healthpb "google.golang.org/grpc/health/grpc_health_v1"
 	"google.golang.org/grpc/metadata"
 	grpcstats "google.golang.org/grpc/stats"
 	"google.golang.org/grpc/status"
@@ -24,6 +26,7 @@ import (
 	"google.golang.org/protobuf/encoding/prototext"
 	"google.golang.org/protobuf/proto"
 	"google.golang.org/protobuf/reflect/protoreflect"
+	"google.golang.org/protobuf/reflect/protoregistry"
 	"google.golang.org/protobuf/types/descriptorpb"
 	"google.golang.org/protobuf/types/dynamicpb"
 	"google.golang.org/protobuf/types/known/emptypb"
@@ -59,6 +62,11 @@ type StreamRequest struct {
 	Metadata               metadata.MD
 }
 
+// HealthCheckResponse represents a gRPC healthcheck response.
+type HealthCheckResponse struct {
+	Status healthpb.HealthCheckResponse_ServingStatus
+}
+
 type clientConnCloser interface {
 	grpc.ClientConnInterface
 	Close() error
@@ -66,7 +74,8 @@ type clientConnCloser interface {
 
 // Conn is a gRPC client connection.
 type Conn struct {
-	raw clientConnCloser
+	raw   clientConnCloser
+	types *protoregistry.Types
 }
 
 // DefaultOptions generates an option set
@@ -87,14 +96,15 @@ func DefaultOptions(getState func() *lib.State) []grpc.DialOption {
 }
 
 // Dial establish a gRPC connection.
-func Dial(ctx context.Context, addr string, options ...grpc.DialOption) (*Conn, error) {
+func Dial(ctx context.Context, addr string, types *protoregistry.Types, options ...grpc.DialOption) (*Conn, error) {
 	//nolint:staticcheck // see https://github.com/grafana/k6/issues/3699
 	conn, err := grpc.DialContext(ctx, addr, options...)
 	if err != nil {
 		return nil, err
 	}
 	return &Conn{
-		raw: conn,
+		raw:   conn,
+		types: types,
 	}, nil
 }
 
@@ -104,6 +114,17 @@ func (c *Conn) Reflect(ctx context.Context) (*descriptorpb.FileDescriptorSet, er
 	return rc.Reflect(ctx)
 }
 
+// HealthCheck executes a unary gRPC healthcheck Check call.
+func (c *Conn) HealthCheck(ctx context.Context, svc string) (*HealthCheckResponse, error) {
+	healthClient := healthpb.NewHealthClient(c.raw)
+	res, err := healthClient.Check(ctx, &healthpb.HealthCheckRequest{Service: svc})
+	if err != nil {
+		return nil, err
+	}
+
+	return &HealthCheckResponse{Status: res.GetStatus()}, nil
+}
+
 // Invoke executes a unary gRPC request.
 func (c *Conn) Invoke(
 	ctx context.Context,
@@ -130,7 +151,7 @@ func (c *Conn) Invoke(
 	ctx = metadata.NewOutgoingContext(ctx, req.Metadata)
 
 	reqdm := dynamicpb.NewMessage(req.MethodDescriptor.Input())
-	if err := protojson.Unmarshal(req.Message, reqdm); err != nil {
+	if err := (protojson.UnmarshalOptions{Resolver: c.types}).Unmarshal(req.Message, reqdm); err != nil {
 		return nil, fmt.Errorf("unable to serialise request object to protocol buffer: %w", err)
 	}
 
@@ -156,7 +177,7 @@ func (c *Conn) Invoke(
 		Trailers: trailer,
 	}
 
-	marshaler := protojson.MarshalOptions{EmitUnpopulated: true}
+	marshaler := protojson.MarshalOptions{EmitUnpopulated: true, Resolver: c.types}
 
 	if err != nil {
 		sterr := status.Convert(err)
@@ -209,6 +230,8 @@ func (c *Conn) NewStream(
 		method:                 req.Method,
 		methodDescriptor:       req.MethodDescriptor,
 		discardResponseMessage: req.DiscardResponseMessage,
+		marshaler:              protojson.MarshalOptions{Resolver: c.types, EmitUnpopulated: true},
+		unmarshaler:            protojson.UnmarshalOptions{Resolver: c.types},
 	}, nil
 }
 
