@@ -32,7 +32,7 @@ func TestNew(t *testing.T) {
 	o.logger.Info("aaa")
 	loglines := hook.Drain()
 	require.Len(t, loglines, 1)
-	assert.Equal(t, loglines[0].Data["output"], "cloudv2")
+	assert.Equal(t, "cloudv2", loglines[0].Data["output"])
 
 	// assert the config set
 	assert.Equal(t, int64(99), o.config.APIVersion.Int64)
